from .depss.dep import *          # imports everything from dep.py
from .decorators.decorator import *  # imports mark, parameters, timeout, retry, etc.
from .helpers.helper import *      # import helper functions (e.g., color_text, config, logger, etc.)
from .plugins.plugin import *      # import your Plugin base class, etc.
from .plugins.trelloplugin import *
from .reports.report import *      # import generate_json_report, generate_html_report, etc.
from .testcases.coreex import *    # extended test core functionality
from .testcases.testbase import *  # core TestCase base class
from .testcases.testsuite import * # TestSuite class and execution orchestration

__version__ = "1.1.0"
